# Example - Simple search
This example shows how to perform an advanced search on the PubMed database and retrieve information about the relevant articles.

You can use [PubMed query builder](https://www.ncbi.nlm.nih.gov/pubmed/advanced) for creating the query syntax.

